@@ -3,7 +3,6 @@
 # SPDX-License-Identifier: MIT
 import time
 import board
-import busio
 
 # pylint:disable=no-member
 from adafruit_lsm6ds import Rate, AccelRange, GyroRange
@@ -14,8 +13,7 @@ from adafruit_lsm6ds.lsm6dsox import LSM6DSOX as LSM6DS
 # from adafruit_lsm6ds.lsm6dso32 import LSM6DSO32 as LSM6DS
 # from adafruit_lsm6ds.ism330dhcx import ISM330DHCX as LSM6DS
 
-i2c = busio.I2C(board.SCL, board.SDA)
-
+i2c = board.I2C()  # uses board.SCL and board.SDA
 sensor = LSM6DS(i2c)
 
 sensor.accelerometer_range = AccelRange.RANGE_8G
