@@ -7,14 +7,12 @@ the chip so you don't have to do any calculations!"""
 
 import time
 import board
-import busio
 
 # pylint:disable=no-member
 from adafruit_lsm6ds.lsm6ds33 import LSM6DS33
 from adafruit_lsm6ds import Rate, AccelRange
 
-i2c = busio.I2C(board.SCL, board.SDA)
-
+i2c = board.I2C()  # uses board.SCL and board.SDA
 sensor = LSM6DS33(i2c)
 
 # enable accelerometer sensor @ 2G and 26 Hz
